==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/MonthlyRetentionScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.RetentionScheduleFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Monthly retention schedule.
 * @property retentionDuration Retention duration of retention Policy.
 * @property retentionScheduleDaily Daily retention format for monthly retention policy.
 * @property retentionScheduleFormatType Retention schedule format type for monthly retention policy.
 * @property retentionScheduleWeekly Weekly retention format for monthly retention policy.
 * @property retentionTimes Retention times of retention policy.
 */
public data class MonthlyRetentionScheduleArgs(
    public val retentionDuration: Output<RetentionDurationArgs>? = null,
    public val retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null,
    public val retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null,
    public val retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null,
    public val retentionTimes: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs =
        com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs.builder()
            .retentionDuration(retentionDuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionScheduleDaily(
                retentionScheduleDaily?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionScheduleFormatType(
                retentionScheduleFormatType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .retentionScheduleWeekly(
                retentionScheduleWeekly?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionTimes(retentionTimes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [MonthlyRetentionScheduleArgs].
 */
@PulumiTagMarker
public class MonthlyRetentionScheduleArgsBuilder internal constructor() {
    private var retentionDuration: Output<RetentionDurationArgs>? = null

    private var retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null

    private var retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null

    private var retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null

    private var retentionTimes: Output<List<String>>? = null

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("pcoufikuancffpwy")
    public suspend fun retentionDuration(`value`: Output<RetentionDurationArgs>) {
        this.retentionDuration = value
    }

    /**
     * @param value Daily retention format for monthly retention policy.
     */
    @JvmName("fxjntfkreoouvkrf")
    public suspend fun retentionScheduleDaily(`value`: Output<DailyRetentionFormatArgs>) {
        this.retentionScheduleDaily = value
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("pjosfiebspidmdel")
    public suspend
    fun retentionScheduleFormatType(`value`: Output<Either<String, RetentionScheduleFormat>>) {
        this.retentionScheduleFormatType = value
    }

    /**
     * @param value Weekly retention format for monthly retention policy.
     */
    @JvmName("rywqcwjrlyalhtoj")
    public suspend fun retentionScheduleWeekly(`value`: Output<WeeklyRetentionFormatArgs>) {
        this.retentionScheduleWeekly = value
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("iqgksydckkyjoaag")
    public suspend fun retentionTimes(`value`: Output<List<String>>) {
        this.retentionTimes = value
    }

    @JvmName("gdqewdygrwaprxpd")
    public suspend fun retentionTimes(vararg values: Output<String>) {
        this.retentionTimes = Output.all(values.asList())
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("ruwedrokstvviokg")
    public suspend fun retentionTimes(values: List<Output<String>>) {
        this.retentionTimes = Output.all(values)
    }

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("pfjljbtamfgcrpky")
    public suspend fun retentionDuration(`value`: RetentionDurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionDuration = mapped
    }

    /**
     * @param argument Retention duration of retention Policy.
     */
    @JvmName("aiwkhxkxogvnqloa")
    public suspend fun retentionDuration(argument: suspend RetentionDurationArgsBuilder.() -> Unit) {
        val toBeMapped = RetentionDurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionDuration = mapped
    }

    /**
     * @param value Daily retention format for monthly retention policy.
     */
    @JvmName("jcpnchgvllsbgbsf")
    public suspend fun retentionScheduleDaily(`value`: DailyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param argument Daily retention format for monthly retention policy.
     */
    @JvmName("twsvtpgtmgsgjntj")
    public suspend
    fun retentionScheduleDaily(argument: suspend DailyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = DailyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("ytvdpdlxnklprvkw")
    public suspend
    fun retentionScheduleFormatType(`value`: Either<String, RetentionScheduleFormat>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("astakdnaogbrimjn")
    public fun retentionScheduleFormatType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("ivxsontugkbwvyla")
    public fun retentionScheduleFormatType(`value`: RetentionScheduleFormat) {
        val toBeMapped = Either.ofRight<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Weekly retention format for monthly retention policy.
     */
    @JvmName("hfhserwxtuutblsi")
    public suspend fun retentionScheduleWeekly(`value`: WeeklyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param argument Weekly retention format for monthly retention policy.
     */
    @JvmName("rlctjiqkgkysyevn")
    public suspend
    fun retentionScheduleWeekly(argument: suspend WeeklyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = WeeklyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("vqmgsdrigbjrieqw")
    public suspend fun retentionTimes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("laitovaywmapbxct")
    public suspend fun retentionTimes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    internal fun build(): MonthlyRetentionScheduleArgs = MonthlyRetentionScheduleArgs(
        retentionDuration = retentionDuration,
        retentionScheduleDaily = retentionScheduleDaily,
        retentionScheduleFormatType = retentionScheduleFormatType,
        retentionScheduleWeekly = retentionScheduleWeekly,
        retentionTimes = retentionTimes,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/MonthlyRetentionScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.RetentionScheduleFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Monthly retention schedule.
 * @property retentionDuration Retention duration of retention Policy.
 * @property retentionScheduleDaily Daily retention format for monthly retention policy.
 * @property retentionScheduleFormatType Retention schedule format type for monthly retention policy.
 * @property retentionScheduleWeekly Weekly retention format for monthly retention policy.
 * @property retentionTimes Retention times of retention policy.
 */
public data class MonthlyRetentionScheduleArgs(
    public val retentionDuration: Output<RetentionDurationArgs>? = null,
    public val retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null,
    public val retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null,
    public val retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null,
    public val retentionTimes: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs =
        com.pulumi.azurenative.workloads.inputs.MonthlyRetentionScheduleArgs.builder()
            .retentionDuration(retentionDuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionScheduleDaily(
                retentionScheduleDaily?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionScheduleFormatType(
                retentionScheduleFormatType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .retentionScheduleWeekly(
                retentionScheduleWeekly?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionTimes(retentionTimes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [MonthlyRetentionScheduleArgs].
 */
@PulumiTagMarker
public class MonthlyRetentionScheduleArgsBuilder internal constructor() {
    private var retentionDuration: Output<RetentionDurationArgs>? = null

    private var retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null

    private var retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null

    private var retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null

    private var retentionTimes: Output<List<String>>? = null

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("dfukupnwiacswkdv")
    public suspend fun retentionDuration(`value`: Output<RetentionDurationArgs>) {
        this.retentionDuration = value
    }

    /**
     * @param value Daily retention format for monthly retention policy.
     */
    @JvmName("apwjtlpkmsngvkjw")
    public suspend fun retentionScheduleDaily(`value`: Output<DailyRetentionFormatArgs>) {
        this.retentionScheduleDaily = value
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("erqpmmmiddrjhjaa")
    public suspend
    fun retentionScheduleFormatType(`value`: Output<Either<String, RetentionScheduleFormat>>) {
        this.retentionScheduleFormatType = value
    }

    /**
     * @param value Weekly retention format for monthly retention policy.
     */
    @JvmName("tqlgduhrnvtyhlas")
    public suspend fun retentionScheduleWeekly(`value`: Output<WeeklyRetentionFormatArgs>) {
        this.retentionScheduleWeekly = value
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("iwfmicfcayvjxrvd")
    public suspend fun retentionTimes(`value`: Output<List<String>>) {
        this.retentionTimes = value
    }

    @JvmName("auurhmuujbcfdoxw")
    public suspend fun retentionTimes(vararg values: Output<String>) {
        this.retentionTimes = Output.all(values.asList())
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("cohcrusijsfnrtlm")
    public suspend fun retentionTimes(values: List<Output<String>>) {
        this.retentionTimes = Output.all(values)
    }

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("iyydquqrpdvnheym")
    public suspend fun retentionDuration(`value`: RetentionDurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionDuration = mapped
    }

    /**
     * @param argument Retention duration of retention Policy.
     */
    @JvmName("qdwmagrmixeyfemy")
    public suspend fun retentionDuration(argument: suspend RetentionDurationArgsBuilder.() -> Unit) {
        val toBeMapped = RetentionDurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionDuration = mapped
    }

    /**
     * @param value Daily retention format for monthly retention policy.
     */
    @JvmName("plkwdqhtmqotefsa")
    public suspend fun retentionScheduleDaily(`value`: DailyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param argument Daily retention format for monthly retention policy.
     */
    @JvmName("innleugnncmyeuyo")
    public suspend
    fun retentionScheduleDaily(argument: suspend DailyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = DailyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("ytisusndomqcrunv")
    public suspend
    fun retentionScheduleFormatType(`value`: Either<String, RetentionScheduleFormat>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("papqhfdxvqthbknb")
    public fun retentionScheduleFormatType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format type for monthly retention policy.
     */
    @JvmName("tjjshaoeaqwmnqrf")
    public fun retentionScheduleFormatType(`value`: RetentionScheduleFormat) {
        val toBeMapped = Either.ofRight<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Weekly retention format for monthly retention policy.
     */
    @JvmName("ufaajxiyovxcijik")
    public suspend fun retentionScheduleWeekly(`value`: WeeklyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param argument Weekly retention format for monthly retention policy.
     */
    @JvmName("bpwufffsckfpeuif")
    public suspend
    fun retentionScheduleWeekly(argument: suspend WeeklyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = WeeklyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("nylgymixbdvgucex")
    public suspend fun retentionTimes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("lpijnlitoynrhsqt")
    public suspend fun retentionTimes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    internal fun build(): MonthlyRetentionScheduleArgs = MonthlyRetentionScheduleArgs(
        retentionDuration = retentionDuration,
        retentionScheduleDaily = retentionScheduleDaily,
        retentionScheduleFormatType = retentionScheduleFormatType,
        retentionScheduleWeekly = retentionScheduleWeekly,
        retentionTimes = retentionTimes,
    )
}
